@@ -73,7 +73,7 @@ def train_from_folder(
     new = False,
     load_from = -1,
     image_size = 256,
-    optimizer="adam",
+    optimizer = 'adam',
     fmap_max = 512,
     transparent = False,
     batch_size = 10,
@@ -91,7 +91,7 @@ def train_from_folder(
     num_image_tiles = 8,
     trunc_psi = 0.75,
     aug_prob = 0.,
-    aug_types = ['cutout'],
+    aug_types = ['cutout', 'translation'],
     dataset_aug_prob = 0.,
     multi_gpus = False,
     calculate_fid_every = None,
